@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -26,6 +26,9 @@
 #include "CSettings.h"
 
 #include <QtGui>
+#include <QFileDialog>
+#include <QScrollBar>
+#include <QMessageBox>
 
 static bool tileIndexLessThan(const QPair<int, int> &i1, const QPair<int, int> &i2)
 {
@@ -82,7 +85,6 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     lineDescription->setText(mapData.description);
     lineDescription->setCursorPosition(0);
 
-#ifdef HAS_RMAP
     radioRMAP->show();
     radioRMAP->setEnabled(true);
 
@@ -91,11 +93,6 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     comboRmapProjection->addItem("EPSG:31467, GK3 (DHDN)", "+init=epsg:31467");
     comboRmapProjection->addItem("EPSG:31468, GK4 (DHDN)", "+init=epsg:31468");
 
-#else
-    radioRMAP->hide();
-    radioRMAP->setDisabled(true);
-#endif
-
 #ifdef WIN32
     path_map2jnx        = QCoreApplication::applicationDirPath()+QDir::separator()+"map2jnx.exe";
     QFile file_map2jnx(path_map2jnx);
@@ -105,7 +102,7 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     path_map2rmap       = QCoreApplication::applicationDirPath()+QDir::separator()+"map2rmap.exe";
     path_map2rmp        = QCoreApplication::applicationDirPath()+QDir::separator()+"map2rmp.exe";
 #else
-#if defined(Q_WS_MAC)
+#if defined(Q_OS_MAC)
     // MacOS X: applications are stored in the bundle folder
     path_map2gcm        = QString("%1/Resources/map2gcm").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
     path_map2jnx        = QString("%1/Resources/map2jnx").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
@@ -196,8 +193,6 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
         groupStreaming->show();
     }
 
-
-
     QFont f = font();
     f.setFamily("Mono");
     textBrowser->setFont(f);
@@ -359,6 +354,7 @@ void CMapQMAPExport::slotRMAPToggled(bool checked)
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotRMPToggled(bool checked)
 {
     if(checked)
@@ -384,6 +380,7 @@ void CMapQMAPExport::slotRMPToggled(bool checked)
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotSelectCopyright()
 {
     copyright = QFileDialog::getOpenFileName(0, tr("Select copyright notice..."),"./", tr("text file (*.txt)"), 0, FILE_DIALOG_FLAGS);
@@ -397,6 +394,7 @@ void CMapQMAPExport::slotSelectCopyright()
 
 }
 
+
 void CMapQMAPExport::slotStderr()
 {
     QString str;
@@ -929,7 +927,6 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
         states << state5;
     }
 
-
 }
 
 
@@ -1571,6 +1568,7 @@ void CMapExportStateRMAP::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateRMP::CMapExportStateRMP(const QString& app, CMapQMAPExport * parent)
 : IMapExportState(parent)
